<?php

namespace FiloBlu\Refilo\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\DataObject;
use Magento\Framework\UrlInterface;
use Magento\Store\Model\ResourceModel\Store\CollectionFactory as StoreCollectionFactory;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\Store;

/**
 * Class Data
 * @package FiloBlu\Refilo\Helper
 */
class Data extends AbstractHelper
{

    /**
     * @var StoreCollectionFactory
     */
    protected $storeCollectionFactory;
    /**
     * @var DataObject
     */
    protected $dataObject;

    /**
     * const
     */
    const XML_USE_SECURE_IN_FRONTEND = "web/secure/use_in_frontend";

    /**
     * Data constructor.
     * @param Context $context
     * @param StoreCollectionFactory $storeCollectionFactory
     * @param DataObject $dataObject
     */
    public function __construct(
        Context $context,
        StoreCollectionFactory $storeCollectionFactory,
        DataObject $dataObject
    ) {
        $this->storeCollectionFactory = $storeCollectionFactory;
        $this->dataObject = $dataObject;
        parent::__construct($context);
    }

    /**
     * @param $field
     * @return mixed
     */
    public function getConfigValue($field)
    {
        return $this->scopeConfig->getValue($field);
    }

    /**
     * @param $storeId
     * @return string
     */
    public function getFrontendUrl($storeId)
    {
        list($storeConfig, $lookupConfigs) = $this->getStoreConfigs($storeId);
        if (count($lookupConfigs[$storeConfig[$storeId]["base_url"]]) > 1) {
            return $storeConfig[$storeId]["base_url"] . $storeConfig[$storeId]["code"] . "/";
        }
        return $storeConfig[$storeId]["base_url"];
    }

    /**
     * @return array[]
     */
    public function getStoreConfigs()
    {
        $storeConfigs = [];
        $lookupConfigs = [];
        $storeCollection = $this->storeCollectionFactory->create();

        $collection = $storeCollection->load();
        foreach ($collection as $item) {
            $config = $this->getStoreConfig($item);
            $url = ((bool)$config->getData("use_secure_url")==true) ? $config->getSecureBaseUrl() : $config->getBaseUrl();
            $storeConfigs[$config->getId()] = [
                "code" => $config->getCode(),
                "base_url" => $url
            ];
            $lookupConfigs[$url][] = $config->getCode();
        }
        return [$storeConfigs,$lookupConfigs];
    }

    /**
     * @param Store $store
     * @return DataObject
     */
    public function getStoreConfig(Store $store)
    {
        $storeConfig = $this->dataObject;

        $storeConfig->setId($store->getId())
            ->setCode($store->getCode())
            ->setWebsiteId($store->getWebsiteId());

        $useSecure = $this->scopeConfig->isSetFlag(
            self::XML_USE_SECURE_IN_FRONTEND,
            ScopeInterface::SCOPE_STORES,
            $store->getCode()
        );

        $storeConfig->setData("use_secure_url", $useSecure);
        $storeConfig->setBaseUrl($store->getBaseUrl(UrlInterface::URL_TYPE_WEB, false));
        $storeConfig->setSecureBaseUrl($store->getBaseUrl(UrlInterface::URL_TYPE_WEB, true));
        $storeConfig->setBaseLinkUrl($store->getBaseUrl(UrlInterface::URL_TYPE_LINK, false));
        $storeConfig->setSecureBaseLinkUrl($store->getBaseUrl(UrlInterface::URL_TYPE_LINK, true));
        $storeConfig->setBaseStaticUrl($store->getBaseUrl(UrlInterface::URL_TYPE_STATIC, false));
        $storeConfig->setSecureBaseStaticUrl(
            $store->getBaseUrl(UrlInterface::URL_TYPE_STATIC, true)
        );
        $storeConfig->setBaseMediaUrl($store->getBaseUrl(UrlInterface::URL_TYPE_MEDIA, false));
        $storeConfig->setSecureBaseMediaUrl(
            $store->getBaseUrl(UrlInterface::URL_TYPE_MEDIA, true)
        );
        return $storeConfig;
    }
}
